==> haskell-optics-th-0.4.1-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optics-th
version:              0.4.1
visibility:           public
id:                   optics-th-0.4.1-Fo5OymJLlLZ26s91T5pdeP
key:                  optics-th-0.4.1-Fo5OymJLlLZ26s91T5pdeP
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Optics construction using TemplateHaskell
description:
    This package is part of the @<https://hackage.haskell.org/package/optics optics>@
    package family.  It provides machinery to construct optics using @TemplateHaskell@.

    See the @template-haskell-optics@ package for optics to work with @template-haskell@ types.

category:             Data, Optics, Lenses
abi:                  372478e0d40de77d5b8558e881505d7e
exposed:              True
exposed-modules:
    Optics.TH Optics.TH.Internal.Product Optics.TH.Internal.Sum
    Optics.TH.Internal.Utils

hidden-modules:       Language.Haskell.TH.Optics.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-th
hs-libraries:         HSoptics-th-0.4.1-Fo5OymJLlLZ26s91T5pdeP
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    optics-core-0.4.1.1-F75V4WhENuwDvh2NyeghfJ
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-optics-th/html/optics-th.haddock
haddock-html:         /usr/share/doc/haskell-optics-th/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optics-th-0.4.1-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optics-th
version:              0.4.1
visibility:           public
id:                   optics-th-0.4.1-Honziqg2zRfFN9sSuxAtOS
key:                  optics-th-0.4.1-Honziqg2zRfFN9sSuxAtOS
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Optics construction using TemplateHaskell
description:
    This package is part of the @<https://hackage.haskell.org/package/optics optics>@
    package family.  It provides machinery to construct optics using @TemplateHaskell@.

    See the @template-haskell-optics@ package for optics to work with @template-haskell@ types.

category:             Data, Optics, Lenses
abi:                  2639e5b44b20a8c241318e8e878eb6bb
exposed:              True
exposed-modules:
    Optics.TH Optics.TH.Internal.Product Optics.TH.Internal.Sum
    Optics.TH.Internal.Utils

hidden-modules:       Language.Haskell.TH.Optics.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-th
hs-libraries:         HSoptics-th-0.4.1-Honziqg2zRfFN9sSuxAtOS
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    optics-core-0.4.1.1-K0eFdwpH2gr3mMwZccKc03
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-optics-th/html/optics-th.haddock
haddock-html:         /usr/share/doc/haskell-optics-th/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
